@@ -90,11 +90,11 @@ BookmarksDlg::BookmarksDlg(const Bookmarks& bms, TQWidget* parent,
 
 	updateBookmarks();
 	// signals and slots connections
-	connect(buttonOk, TQT_SIGNAL(clicked()), this, TQT_SLOT(accept()));
-	connect(buttonCancel, TQT_SIGNAL(clicked()), this, TQT_SLOT(reject()));
-	connect(addButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(addBookmark()));
-	connect(deleteButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(deleteBookmark()));
-	connect(bookmarksTable, TQT_SIGNAL(valueChanged(int, int)), this, TQT_SLOT(valueChanged(int, int)));
+	connect(buttonOk, TQ_SIGNAL(clicked()), this, TQ_SLOT(accept()));
+	connect(buttonCancel, TQ_SIGNAL(clicked()), this, TQ_SLOT(reject()));
+	connect(addButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(addBookmark()));
+	connect(deleteButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(deleteBookmark()));
+	connect(bookmarksTable, TQ_SIGNAL(valueChanged(int, int)), this, TQ_SLOT(valueChanged(int, int)));
 }
 
 /*
@@ -117,9 +117,7 @@ void BookmarksDlg::languageChange()
 	buttonHelp->setText( tr2i18n( "&Help" ) );
 	buttonHelp->setAccel( TQKeySequence( tr2i18n( "F1" ) ) );
 	buttonOk->setText( tr2i18n( "&OK" ) );
-	buttonOk->setAccel( TQKeySequence( TQString() ) );
 	buttonCancel->setText( tr2i18n( "Ca&ncel" ) );
-	buttonCancel->setAccel( TQKeySequence( tr2i18n( "Alt+N" ) ) );
 }
 
 void BookmarksDlg::addBookmark()
